package com.hungraim.ltc.governance.controller;

import cn.hutool.core.util.StrUtil;
import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.hungraim.ism.pojo.vo.disable.DisableEvaluateVO;
import com.hungraim.ltc.governance.service.*;
import com.hungraim.ltc.pojo.entity.disable.ChDisableApply;
import com.hungraim.ltc.pojo.entity.disable.ChSrvOrgan;
import com.hungraim.ltc.pojo.entity.governance.ChSrvBuildBed;
import com.hungraim.ltc.pojo.vo.governance.BuildBedSearchReq;
import com.hungraim.ltc.util.Result;
import lombok.extern.slf4j.Slf4j;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;

import javax.annotation.Resource;
import javax.servlet.http.HttpServletRequest;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

/**
 * @author jiaguokai
 */
@RestController
@RequestMapping("/api.governance/buildBed")
@Slf4j
public class BuildBedController {
    @Resource
    private IBuildBedService buildBedService;
    @Resource
    private ApplyService applyService;
    @Resource
    private CrvService crvService;

    @Resource
    private DisableEvaluateService disableEvaluateService;



    @PostMapping("/searchOrgBed")
    public Result searchOrgBed(@RequestBody BuildBedSearchReq req) {
        return buildBedService.searchOrgBed(req);
    }

    @PostMapping("/addBuild")
    public Result<Boolean> buildBed(ChSrvBuildBed buildBed) {
        boolean b = buildBedService.save(buildBed);
        return Result.success(b);
    }

    /**
     * 功能描述: 服务分配信息检索条件查询
     */
    @GetMapping("/pageFuwuCondition")
    public Result pageFuwuCondition(HttpServletRequest request,
                                    @RequestBody(required = false) ChDisableApply disableApply) {

        // 创建一个page对象
        Page<ChDisableApply> disableApplyPage = new Page<ChDisableApply>(disableApply.getCurrent(), disableApply.getLimit());
        // 构建条件
        QueryWrapper<ChDisableApply> queryWrapper = new QueryWrapper<>();
        // 多条件组合查询
        // 机构id
        String organid = disableApply.getOrganId();
        // 失能人员姓名
        String name = disableApply.getRealName();
        // 失能人员手机号码
        String tel = disableApply.getTel();
        // 省
        String provincial = disableApply.getDistrictProvincial();
        //　市
        String city = disableApply.getDistrictCity();
        //　县
        String area = disableApply.getDistrictArea();
        // 失能人员身份证号码
        String certiCode = disableApply.getCertiCode();
        // 意向护理机构
        Long srvOrganId = disableApply.getSrvOrganId();
        // 服务方式
        Long srvModeId = disableApply.getSrvModeId();
        // 状态
        Short applyStatus = disableApply.getApplyStatus();

        if (!StrUtil.isEmpty(organid)) {
            queryWrapper.like("organ_id", organid);
        }
        if (!StrUtil.isEmpty(name)) {
            queryWrapper.like("real_name", name);
        }
        if (!StrUtil.isEmpty(tel)) {
            queryWrapper.like("tel", tel);
        }
        if (!StrUtil.isEmpty(city)) {
            queryWrapper.like("district_City", city);
        }
        if (!StrUtil.isEmpty(provincial)) {
            queryWrapper.like("district_Provincial", provincial);
        }
        if (!StrUtil.isEmpty(area)) {
            queryWrapper.like("district_Area", area);
        }
        if (!StrUtil.isEmpty(certiCode)) {
            queryWrapper.like("certi_Code", certiCode);
        }
        if (srvOrganId != null) {
            queryWrapper.like("srv_Organ_Id", srvOrganId);
        }
        if (srvModeId != null) {
            queryWrapper.like("srv_Mode_Id", srvModeId);
        }
        if (applyStatus != null) {
            queryWrapper.like("apply_Status", applyStatus);
        }
        // 调用方法实现分页查询
        Page<ChDisableApply> page = applyService.seletPage(disableApplyPage, queryWrapper);
        //buildBedService.
        // 总记录数
        long total = disableApplyPage.getTotal();
        List<ChDisableApply> records = disableApplyPage.getRecords();
        Map map = new HashMap<>();
        map.put("total", total);
        map.put("recors", records);
        return Result.success(map);
    }

    /**
     * 根据id查询失能人员的评定信息
     */
    @GetMapping("/queryEvaluateById")
    public Result queryEvaluateById (@ModelAttribute ChDisableApply chDisableApply){

        String organId = chDisableApply.getOrganId();
        Long srvOrganId = chDisableApply.getSrvOrganId();
        String realName = chDisableApply.getRealName();
        String certiCode = chDisableApply.getCertiCode();

        IPage<DisableEvaluateVO> disableEvaluateVOIPage = disableEvaluateService.disableEvaluateList(organId, srvOrganId, realName, certiCode, chDisableApply.getCurrent(), chDisableApply.getLimit());

        ChDisableApply page = applyService.selectById(chDisableApply.getApplyId());
        // 查询是能人员最新评定信息

        Map map = new HashMap<>();
        map.put("disableEvaluate", disableEvaluateVOIPage.getRecords());
        map.put("chDisableApply", page);
        return Result.success(map);
    }
    /**
     *护理机构及服务方式檢索
     */
    @GetMapping("/PageCrv")
    public Result PageCrv(HttpServletRequest request,
                          @RequestBody(required = false) ChSrvOrgan chSrvOrgan){

        // 创建一个page对象
        Page<ChSrvOrgan> chSrvOrganPage = new Page<ChSrvOrgan>(chSrvOrgan.getCurrent(), chSrvOrgan.getLimit());
        // 构建条件
        QueryWrapper<ChSrvOrgan> queryWrapper = new QueryWrapper<>();
        // 多条件组合查询
        // 机构id
        String srvid = chSrvOrgan.getOrganId();
        // 机构名称
        String srvOrganName = chSrvOrgan.getSrvOrganName();
        // 社会信用代码
        String code = chSrvOrgan.getUnifiedSocialCreditCode();

        if (!StrUtil.isEmpty(srvid)) {
            queryWrapper.like("organ_id", srvid);
        }
        if (!StrUtil.isEmpty(srvOrganName)) {
            queryWrapper.like("srv_Organ_Name", srvOrganName);
        }
        if (!StrUtil.isEmpty(code)) {
            queryWrapper.like("unified_social_credit_code", code);
        }
        // 调用方法实现分页查询
        Page<ChSrvOrgan> page = crvService.seletPage(chSrvOrganPage, queryWrapper);
        //buildBedService.
        // 总记录数
        long total = chSrvOrganPage.getTotal();
        List<ChSrvOrgan> records = chSrvOrganPage.getRecords();
        Map map = new HashMap<>();
        map.put("total", total);
        map.put("recors", records);
        return Result.success(map);
    }

    /**
     *提交分配机构
     */
    @PostMapping("/submit")
    public Result submit(@RequestBody(required = false) ChDisableApply  chDisableApply){
        // 判斷參數是否存在
           if (chDisableApply.getApplyId()==null){
               return Result.failed("机构id無效");
           }
       //  查出失能人員相關信息
        ChDisableApply apply = applyService.selectById(chDisableApply.getApplyId());
        ChSrvOrgan chSrvOrgan = new ChSrvOrgan();
        apply.setOrganId(chDisableApply.getOrganId());
        apply.setDistrictProvincial(chDisableApply.getDistrictProvincial());
        apply.setDistrictCity(chDisableApply.getDistrictCity());
        apply.setDistrictArea(chDisableApply.getDistrictArea());
        apply.setSrvModeId(chDisableApply.getSrvModeId());
//        apply.setSrvOrganName(chDisableApply.getSrvOrganName());
//        apply.setOrganTypeId(chSrvOrgan.getOrganTypeId());
//        apply.setUnifiedSocialCreditCode(chSrvOrgan.getUnifiedSocialCreditCode());
//        apply.setSrvType(chSrvOrgan.getSrvType());
        apply.setEndTime(chDisableApply.getEndTime());
        apply.setAcptRoadDetail(chDisableApply.getAcptRoadDetail());
//        apply.setAcptRoadType(chSrvOrgan.getAcptRoadType());
//        crvService.updateById(apply);
        applyService.updateById(apply);
        return Result.success(apply);
    }

}

